Welcome to k2hash's documentation!
==================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   modules
   authors
   history


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
